@@ -8,7 +8,7 @@
 
 // Defined since RNifti v0.10.0, and equal to 100 * (major version) + (minor version). May not
 // change if the API does not change, and in particular never changes with patch level
-#define RNIFTI_VERSION 103
+#define RNIFTI_VERSION 104
 
 // Versions 1 and 2 of the NIfTI reference library are mutually incompatible, but RNifti does some
 // work to get them to play nicely:
@@ -55,7 +55,7 @@
 extern "C" {
 #endif // __cplusplus
 
-extern void niftilib_register_all ();
+extern void niftilib_register_all (void);
 
 #ifdef __cplusplus
 } // extern "C"
